==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/fileops/translations/fileops_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="97"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Aplankas neegzistuoja</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="103"/>
        <source>Copying</source>
        <translation>Kopijuoju</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="104"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="134"/>
        <source>Copying file %1/%2</source>
        <translation>Kopijuoju bylą %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="176"/>
        <source>Remove files</source>
        <translation>Ištrinti bylas</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="177"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Ar tikri, kad norite ištrinti %n bylų iš kieto disko?</numerusform>
            <numerusform>Ar tikri, kad norite ištrinti %n bylų iš kieto disko?</numerusform>
            <numerusform>Ar tikri, kad norite ištrinti %n bylų iš kieto disko?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Bylų įskiepis</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>Apie bylų įskiepį</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Qmmp bylų įskiepis</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Pakeisti klavišo funkciją</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Paspauskiteklavišų kombinaciją, į kurią norite pakeisti</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="55"/>
        <location filename="../settingsdialog.cpp" line="135"/>
        <source>Remove</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="138"/>
        <source>New action</source>
        <translation>Naujas veiksmas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="192"/>
        <source>Artist</source>
        <translation>Atlikėjas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="193"/>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="194"/>
        <source>Title</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="195"/>
        <source>Tracknumber</source>
        <translation>Takelio numeris</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="196"/>
        <source>Genre</source>
        <translation>Žanras</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="197"/>
        <source>Filename</source>
        <translation>Bylos pavadinimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="198"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="199"/>
        <source>Year</source>
        <translation>Metai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="200"/>
        <source>Comment</source>
        <translation>Komentaras</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="216"/>
        <source>Choose a directory</source>
        <translation>Pasirinkite aplanką</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Bylų operacijų nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Įjungta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Operacija</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Meniu tekstas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Mygtuko nuoroda</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <location filename="../settingsdialog.ui" line="121"/>
        <location filename="../settingsdialog.ui" line="158"/>
        <location filename="../settingsdialog.ui" line="175"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="148"/>
        <source>Destination:</source>
        <translation>Paskirtis:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>File name pattern:</source>
        <translation>Bylos plėtinys:</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/General/fileops/translations/fileops_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <location filename="../fileops.cpp" line="132"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Aplankas neegzistuoja</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="136"/>
        <source>Move Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="137"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="153"/>
        <source>Copying</source>
        <translation>Kopijuoju</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <location filename="../fileops.cpp" line="244"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="199"/>
        <source>Copying file %1/%2</source>
        <translation>Kopijuoju bylą %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="243"/>
        <source>Moving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="276"/>
        <source>Moving file %1/%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="114"/>
        <source>Remove Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="115"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Ar tu tikras, jog nori ištrinti  %n bylą(as) iš disko?</numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="31"/>
        <source>File Operations Plugin</source>
        <translation>Bylų įskiepis</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>About File Operations Plugin</source>
        <translation>Apie bylų įskiepį</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Qmmp bylų įskiepis</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Pakeisti klavišo funkciją</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Paspauskiteklavišų kombinaciją, į kurią norite pakeisti</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>Naujas veiksmas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="220"/>
        <source>Artist</source>
        <translation>Atlikėjas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="222"/>
        <source>Album Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="223"/>
        <source>Title</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="224"/>
        <source>Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="225"/>
        <source>Two-digit Track Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="226"/>
        <source>Genre</source>
        <translation>Žanras</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="230"/>
        <source>Disc Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>File Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="233"/>
        <source>Year</source>
        <translation>Metai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="227"/>
        <source>Comment</source>
        <translation>Komentaras</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="228"/>
        <source>Composer</source>
        <translation>Autorius</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="229"/>
        <source>Duration</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="234"/>
        <source>Condition</source>
        <translation>Būklė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="247"/>
        <source>Choose a directory</source>
        <translation>Pasirinkite aplanką</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Bylų operacijų nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Įjungta</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Operacija</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Meniu tekstas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Mygtuko nuoroda</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Paskirtis:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Bylos plėtinys:</translation>
    </message>
</context>
</TS>
